@@ -47,6 +47,7 @@ extra_actions = {
     gitlab.Project: {SEARCH: {'requiredAttrs': ['query']},
                      OWNED: {'requiredAttrs': []},
                      ALL: {'requiredAttrs': []}},
+    gitlab.Group: {SEARCH: {'requiredAttrs': ['query']}},
 }
 
 
@@ -66,8 +67,7 @@ def clsToWhat(cls):
 def populate_sub_parser_by_class(cls, sub_parser):
     for action_name in ACTIONS:
         attr = 'can' + action_name.capitalize()
-        y = getattr(cls, attr) or getattr(gitlab.GitlabObject, attr)
-        if not y:
+        if not getattr(cls, attr):
             continue
         sub_parser_action = sub_parser.add_parser(action_name)
         [sub_parser_action.add_argument("--%s" % x.replace('_', '-'),
@@ -149,8 +149,7 @@ def do_create(cls, gl, what, args):
         die("%s objects can't be created" % what)
 
     try:
-        o = cls(gl, args)
-        o.save()
+        o = cls.create(gl, args)
     except Exception as e:
         die("Impossible to create object (%s)" % str(e))
 
@@ -170,7 +169,7 @@ def do_list(cls, gl, what, args):
 
 
 def do_get(cls, gl, what, args):
-    if not cls.canGet:
+    if cls.canGet is False:
         die("%s objects can't be retrieved" % what)
 
     id = None
@@ -178,7 +177,7 @@ def do_get(cls, gl, what, args):
         id = get_id(cls, args)
 
     try:
-        o = cls(gl, id, **args)
+        o = cls.get(gl, id, **args)
     except Exception as e:
         die("Impossible to get object (%s)" % str(e))
 
@@ -211,23 +210,30 @@ def do_update(cls, gl, what, args):
     return o
 
 
+def do_group_search(gl, what, args):
+    try:
+        return gl.groups.search(args['query'])
+    except Exception as e:
+        die("Impossible to search projects (%s)" % str(e))
+
+
 def do_project_search(gl, what, args):
     try:
-        return gl.search_projects(args['query'])
+        return gl.projects.search(args['query'])
     except Exception as e:
         die("Impossible to search projects (%s)" % str(e))
 
 
 def do_project_all(gl, what, args):
     try:
-        return gl.all_projects()
+        return gl.projects.all()
     except Exception as e:
         die("Impossible to list all projects (%s)" % str(e))
 
 
 def do_project_owned(gl, what, args):
     try:
-        return gl.owned_projects()
+        return gl.projects.owned()
     except Exception as e:
         die("Impossible to list owned projects (%s)" % str(e))
 
@@ -241,13 +247,15 @@ def main():
     parser.add_argument("-c", "--config-file", action='append',
                         help=("Configuration file to use. Can be used "
                               "multiple times."))
-    parser.add_argument("--gitlab",
+    parser.add_argument("-g", "--gitlab",
                         help=("Which configuration section should "
                               "be used. If not defined, the default selection "
                               "will be used."),
                         required=False)
 
-    subparsers = parser.add_subparsers(dest='what')
+    subparsers = parser.add_subparsers(title='object', dest='what',
+                                       help="Object to manipulate.")
+    subparsers.required = True
 
     # populate argparse for all Gitlab Object
     classes = []
@@ -263,8 +271,10 @@ def main():
         arg_name = clsToWhat(cls)
         object_group = subparsers.add_parser(arg_name)
 
-        object_subparsers = object_group.add_subparsers(dest='action')
+        object_subparsers = object_group.add_subparsers(
+            dest='action', help="Action to execute.")
         populate_sub_parser_by_class(cls, object_subparsers)
+        object_subparsers.required = True
 
     arg = parser.parse_args()
     args = arg.__dict__
@@ -310,10 +320,15 @@ def main():
         getattr(o, action)()
 
     elif action == SEARCH:
-        if cls != gitlab.Project:
+
+        if cls == gitlab.Project:
+            l = do_project_search(gl, what, args)
+        elif cls == gitlab.Group:
+            l = do_group_search(gl, what, args)
+        else:
             die("%s objects don't support this request" % what)
 
-        for o in do_project_search(gl, what, args):
+        for o in l:
             o.display(verbose)
 
     elif action == OWNED:
